==> eclipse-orion-0.5-linux.gtk.x86.zip: web/orion/nls/root/messages.js <==
/*******************************************************************************
 * @license
 * Copyright (c) 2012 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials are made 
 * available under the terms of the Eclipse Public License v1.0 
 * (http://www.eclipse.org/legal/epl-v10.html), and the Eclipse Distribution 
 * License v1.0 (http://www.eclipse.org/org/documents/edl-v10.html). 
 * 
 ******************************************************************************/

//NLS_CHARSET=UTF-8

define({
	"Navigator": "Navigator",
	"Sites": "Sites",
	"Repositories": "Repositories",
	"Console": "Console",
	"Get Plugins": "Get Plugins",
	"Global": "Global",
	"Editor": "Editor",
	"View on Site": "View on Site",
	"View this file or folder on a web site hosted by Orion": "View this file or folder on a web site hosted by Orion",
	"Show a list of all the keybindings on this page": "Show a list of all the keybindings on this page",
	"Show Keys": "Show Keys",
	"Hide or show the page banner and footer": "Hide or show the page banner and footer",
	"Toggle banner and footer": "Toggle banner and footer",
	"Choose a file by name and open an editor on it": "Choose a file by name and open an editor on it",
	"Find File Named...": "Find File Named...",
	"System Configuration Details": "System Configuration Details",
	"System Config Tooltip": "Go to the System Configuration Details page",
	"Background Operations": "Background Operations",
	"Background Operations Tooltip": "Go to the Background Operations page",
	"Operation status is unknown": "Operation status is unknown",
	" is already a favorite.": " is already a favorite.",
	"Add to the favorites list": "Add to the favorites list",
	"Make Favorite": "Make Favorite",
	"Unknown item": "Unknown item",
	"Can't search: no search service is available": "Can't search: no search service is available",
	"could not find banner parent, id was ": "could not find banner parent, id was ",
	" has been added to the favorites list.": " has been added to the favorites list.",
	"Related": "Related",
	"Options": "Options",
	"FAQ": "FAQ",
	"Report a Bug": "Report a Bug",
	"Privacy Policy": "Privacy Policy",
	"Terms of Use": "Terms of Use",
	"Copyright Agent": "Copyright Agent",
	"Orion Logo": "Orion Logo",
	"Type a keyword or wild card to search in root": "Type a keyword or wild card to search in root",
	"Orion is in Beta. Please try it out but BEWARE your data may be lost.": "Beta build I20120622-1139. Please try it out but BEWARE your data may be lost.",
	"Add this page to the favorites list": "Add this page to the favorites list",
	"LOG: ": "LOG: ",
	"Switch": "Switch",
	"Switch the type of outliner used": "Switch the type of outliner used",
	"Outliner": "Outliner",
	"no parent": "no parent",
	"no tree model": "no tree model",
	"no renderer": "no renderer",
	"could not find table row ": "could not find table row ",
	"Resource is out of sync with the server. Do you want to save it anyway?": "Resource is out of sync with the server. Do you want to save it anyway?",
	"Orion Home": "Orion Home",
	"Operations - Press spacebar to show current operations": "Operations - Press spacebar to show current operations",
	"Operations": "Operations",
	"Operations running": "Operations running",
	"Some operations finished with warning": "Some operations finished with warning",
	"Some operations finished with error": "Some operations finished with error",
	"no service registry": "no service registry",
	"Are you sure you want to delete '${0}' from the favorites?": "Are you sure you want to delete '${0}' from the favorites?",
	"Are you sure you want to delete these ${0} favorites?": "Are you sure you want to delete these ${0} favorites?",
	"You can create favorites by selecting any file or folder in the navigator and choosing ${0} from the More menu.": "You can create favorites by selecting any file or folder in the navigator and choosing ${0} from the More menu.",
	"Tasks": "Tasks",
	"Close": "Close",
	"Expand all": "Expand all",
	"Collapse all": "Collapse all" 
});

==> eclipse-orion-2.0-linux.gtk.x86.zip: web/orion/nls/root/messages.js <==
/*******************************************************************************
 * @license
 * Copyright (c) 2012 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials are made 
 * available under the terms of the Eclipse Public License v1.0 
 * (http://www.eclipse.org/legal/epl-v10.html), and the Eclipse Distribution 
 * License v1.0 (http://www.eclipse.org/org/documents/edl-v10.html). 
 * 
 ******************************************************************************/

//NLS_CHARSET=UTF-8

define({
	"Navigator": "Navigator",
	"Sites": "Sites",
	"Repositories": "Repositories",
	"Shell": "Shell",
	"Get Plugins": "Get Plugins",
	"Global": "Global",
	"Editor": "Editor",
	"Orion Editor": "Orion Editor",
	"View on Site": "View on Site",
	"View this file or folder on a web site hosted by Orion": "View this file or folder on a web site hosted by Orion",
	"Show a list of all the keybindings on this page": "Show a list of all the keybindings on this page",
	"Show Keys": "Show Keys",
	"Hide or show the page banner and footer": "Hide or show the page banner and footer",
	"Toggle banner and footer": "Toggle banner and footer",
	"Choose a file by name and open an editor on it": "Choose a file by name and open an editor on it",
	"Find File Named...": "Find File Named...",
	"System Configuration Details": "System Configuration Details",
	"System Config Tooltip": "Go to the System Configuration Details page",
	"Background Operations": "Background Operations",
	"Background Operations Tooltip": "Go to the Background Operations page",
	"Operation status is unknown": "Operation status is unknown",
	" is already a favorite.": " is already a favorite.",
	"Add to the favorites list": "Add to the favorites list",
	"Make Favorite": "Make Favorite",
	"Unknown item": "Unknown item",
	"Can't search: no search service is available": "Can't search: no search service is available",
	"could not find banner parent, id was ": "could not find banner parent, id was ",
	" has been added to the favorites list.": " has been added to the favorites list.",
	"Related": "Related",
	"Options": "Options",
	"FAQ": "FAQ",
	"Report a Bug": "Report a Bug",
	"Privacy Policy": "Privacy Policy",
	"Terms of Use": "Terms of Use",
	"Copyright Agent": "Copyright Agent",
	"Orion Logo": "Orion Logo",
	"Type a keyword or wild card to search in root": "Type a keyword or wild card to search in root",
	"Orion is in Beta. Please try it out but BEWARE your data may be lost.": "Orion build I20130222-1257. See the FAQ for terms of service",
	"Add this page to the favorites list": "Add this page to the favorites list",
	"LOG: ": "LOG: ",
	"Switch": "Switch",
	"Switch the type of outliner used": "Switch the type of outliner used",
	"Outliner": "Outliner",
	"no parent": "no parent",
	"no tree model": "no tree model",
	"no renderer": "no renderer",
	"could not find table row ": "could not find table row ",
	"Resource is out of sync with the server. Do you want to save it anyway?": "Resource is out of sync with the server. Do you want to save it anyway?",
	"Orion Home": "Orion Home",
	"Operations - Press spacebar to show current operations": "Operations - Press spacebar to show current operations",
	"Operations": "Operations",
	"Operations running": "Operations running",
	"Some operations finished with warning": "Some operations finished with warning",
	"Some operations finished with error": "Some operations finished with error",
	"no service registry": "no service registry",
	"Are you sure you want to delete '${0}' from the favorites?": "Are you sure you want to delete '${0}' from the favorites?",
	"Are you sure you want to delete these ${0} favorites?": "Are you sure you want to delete these ${0} favorites?",
	"You can create favorites by selecting any file or folder in the navigator and choosing ${0} from the More menu.": "You can create favorites by selecting any file or folder in the navigator and choosing ${0} from the More menu.",
	"Tasks": "Tasks",
	"Close": "Close",
	"Expand all": "Expand all",
	"Collapse all": "Collapse all",
	"Search" : "Search",
	"Advanced search" : "Advanced search",
	"Submit" : "Submit",
	"More" : "More",
	"Saved searches" : "Saved searches",
	"Recent searches" : "Recent searches",
	"Open in new tab" : "Open in new tab", 
	"Regular expression" : "Regular expression",
	"Search options" : "Search options",
	"Global search" : "Global search",
	"Orion Home" : "Orion Home",
	"Close notification" : "Close notification",
	"Operations - Press spacebar to show current operations" : "Operations - Press spacebar to show current operations",
	"Type a keyword or wild card to search in root" : "Type a keyword or wild card to search in root",
	"Toggle side panel" : "Toggle side panel",
	"Open or close the side panel": "Open or close the side panel",
	"Projects" : "Projects",
	"Toggle Outliner" : "Toggle Outliner",
	"Sample HTML5 Site": "Sample HTML5 Site",
	"Generate an HTML5 'Hello World' website, including JavaScript, HTML, and CSS files.": "Generate an HTML5 'Hello World' website, including JavaScript, HTML, and CSS files.",
	"Sample Orion Plugin": "Sample Orion Plugin",
	"Generate a sample plugin for integrating with Orion.": "Generate a sample plugin for integrating with Orion."
	
});
